package com.sooka.sponest.monitor.meiqiguan.gps.mapper;

import com.sooka.sponest.monitor.meiqiguan.gps.domain.GasTankHistoricalTrajectory;
import com.sooka.sponest.monitor.meiqiguan.gps.domain.vo.GasTankHistoricalTrajectoryVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * 历史轨迹Mapper接口
 *
 * @author ruoyi
 * @date 2024-09-09
 */
public interface GasTankHistoricalTrajectoryMapper {
    /**
     * 查询历史轨迹
     *
     * @param id 历史轨迹主键
     * @return 历史轨迹
     */
    public GasTankHistoricalTrajectory selectGasTankHistoricalTrajectoryById(Long id);

    /**
     * 查询历史轨迹列表
     *
     * @param gasTankHistoricalTrajectory 历史轨迹
     * @return 历史轨迹集合
     */
    public List<GasTankHistoricalTrajectory> selectGasTankHistoricalTrajectoryList(GasTankHistoricalTrajectory gasTankHistoricalTrajectory);

    /**
     * 新增历史轨迹
     *
     * @param gasTankHistoricalTrajectory 历史轨迹
     * @return 结果
     */
    public int insertGasTankHistoricalTrajectory(GasTankHistoricalTrajectory gasTankHistoricalTrajectory);

    /**
     * 修改历史轨迹
     *
     * @param gasTankHistoricalTrajectory 历史轨迹
     * @return 结果
     */
    public int updateGasTankHistoricalTrajectory(GasTankHistoricalTrajectory gasTankHistoricalTrajectory);

    /**
     * 删除历史轨迹
     *
     * @param id 历史轨迹主键
     * @return 结果
     */
    public int deleteGasTankHistoricalTrajectoryById(Long id);

    /**
     * 批量删除历史轨迹
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGasTankHistoricalTrajectoryByIds(Long[] ids);

    List<GasTankHistoricalTrajectory> selectGasTankHistoricalTrajectoryListByDeviceid(GasTankHistoricalTrajectory gasTankHistoricalTrajectory);

    List<GasTankHistoricalTrajectoryVo> selectHistoricalTrajectoryListByDeviceId(@Param("deviceid") String deviceid);

    List<GasTankHistoricalTrajectoryVo> selectHistoricalTrajectoryListOneByDeviceId(@Param("deviceid") String deviceid);
}
